@@ -1,5 +1,5 @@
 ;; guile-gnome
-;; Copyright (C) 2008,2012 Free Software Foundation, Inc.
+;; Copyright (C) 2008,2012,2014 Free Software Foundation, Inc.
 
 ;; This program is free software; you can redistribute it and/or    
 ;; modify it under the terms of the GNU General Public License as   
@@ -42,7 +42,7 @@
 (define-method (initializations-cg (self <clutter-wrapset>) err)
   (list
    (next-method)
-   "clutter_init (NULL, NULL);\n"
+   "if (clutter_init (NULL, NULL) != CLUTTER_INIT_SUCCESS) exit(1);\n"
    ))
 
 (define-class <clutter-event-type> (<gobject-classed-pointer-type>))
@@ -156,6 +156,34 @@
    ;; unwrap
    (list c-var " = scm_scm_to_clutter_perspective (" scm-var ");\n"))
 
+  (wrap-custom-boxed!
+   "ClutterPoint" "CLUTTER_TYPE_POINT"
+   ;; wrap
+   (list scm-var " = " c-var " ? scm_clutter_point_to_scm (" c-var ") : SCM_BOOL_F;\n")
+   ;; unwrap
+   (list c-var " = scm_scm_to_clutter_point (" scm-var ");\n"))
+
+  (wrap-custom-boxed!
+   "ClutterSize" "CLUTTER_TYPE_SIZE"
+   ;; wrap
+   (list scm-var " = " c-var " ? scm_clutter_size_to_scm (" c-var ") : SCM_BOOL_F;\n")
+   ;; unwrap
+   (list c-var " = scm_scm_to_clutter_size (" scm-var ");\n"))
+
+  (wrap-custom-boxed!
+   "ClutterRect" "CLUTTER_TYPE_RECT"
+   ;; wrap
+   (list scm-var " = " c-var " ? scm_clutter_rect_to_scm (" c-var ") : SCM_BOOL_F;\n")
+   ;; unwrap
+   (list c-var " = scm_scm_to_clutter_rect (" scm-var ");\n"))
+
+  (wrap-custom-boxed!
+   "ClutterMatrix" "CLUTTER_TYPE_MATRIX"
+   ;; wrap
+   (list scm-var " = " c-var " ? scm_clutter_matrix_to_scm (" c-var ") : SCM_BOOL_F;\n")
+   ;; unwrap
+   (list c-var " = scm_scm_to_clutter_matrix (" scm-var ");\n"))
+
   (wrap-opaque-pointer! ws "ClutterInputDevice*")
 
   (wrap-opaque-pointer! ws "ClutterEventSequence*")
