@@ -1,5 +1,5 @@
 /* guile-gnome
- * Copyright (C) 2008 Free Software Foundation, Inc.
+ * Copyright (C) 2008,2012,2014 Free Software Foundation, Inc.
  *
  * clutter-support.c: Support routines for the clutter wrapper
  *
@@ -147,14 +147,22 @@ scm_scm_to_clutter_margin (SCM scm)
 {
     ClutterMargin ret;
     
-    ret.left = scm_to_uint8 (scm_car (scm));
-    ret.right = scm_to_uint8 (scm_cadr (scm));
-    ret.top = scm_to_uint8 (scm_caddr (scm));
-    ret.bottom = scm_to_uint8 (scm_cadddr (scm));
+    ret.left = scm_to_double (scm_car (scm));
+    ret.right = scm_to_double (scm_cadr (scm));
+    ret.top = scm_to_double (scm_caddr (scm));
+    ret.bottom = scm_to_double (scm_cadddr (scm));
 
     return clutter_margin_copy (&ret);
 }
 
+SCM
+wrap_clutter_actor_get_margin (ClutterActor* actor)
+{
+    ClutterMargin margin;
+    clutter_actor_get_margin (actor, &margin);
+    return scm_clutter_margin_to_scm (&margin);
+}
+
 SCM
 scm_clutter_actor_box_to_scm (ClutterActorBox *a)
 {
@@ -251,6 +259,22 @@ _wrap_clutter_color_from_string (const char *name)
         return SCM_BOOL_F;
 }
 
+SCM
+wrap_clutter_actor_get_background_color (ClutterActor* actor)
+{
+    ClutterColor color;
+    clutter_actor_get_background_color (actor, &color);
+    return scm_clutter_color_to_scm (&color);
+}
+
+SCM
+wrap_clutter_text_get_color (ClutterText* text)
+{
+    ClutterColor color;
+    clutter_text_get_color (text, &color);
+    return scm_clutter_color_to_scm (&color);
+}
+
 ClutterUnits*
 wrap_clutter_units_from_pixels (gint px)
 {
@@ -298,3 +322,125 @@ wrap_clutter_units_from_string (const gchar *str)
   clutter_units_from_string (&units, str);
   return clutter_units_copy (&units);
 }
+
+
+/* Since 1.12 */
+
+SCM
+scm_clutter_point_to_scm (ClutterPoint *c)
+{
+    return scm_list_2 (scm_from_double (c->x),
+                       scm_from_double (c->y));
+}
+
+ClutterPoint*
+scm_scm_to_clutter_point (SCM scm)
+{
+    ClutterPoint ret;
+
+    ret.x = scm_to_double (scm_car (scm));
+    ret.y = scm_to_double (scm_cadr (scm));
+
+    return clutter_point_copy (&ret);
+}
+
+SCM
+scm_clutter_size_to_scm (ClutterSize *c)
+{
+    return scm_list_2 (scm_from_double (c->width),
+                       scm_from_double (c->height));
+}
+
+ClutterSize*
+scm_scm_to_clutter_size (SCM scm)
+{
+    ClutterSize ret;
+
+    ret.width = scm_to_double (scm_car (scm));
+    ret.height = scm_to_double (scm_cadr (scm));
+
+    return clutter_size_copy (&ret);
+}
+
+SCM
+scm_clutter_rect_to_scm (ClutterRect *rect)
+{
+  return scm_list_4 (scm_from_double (rect->origin.x),
+		     scm_from_double (rect->origin.y),
+		     scm_from_double (rect->size.width),
+		     scm_from_double (rect->size.height));
+}
+
+ClutterRect*
+scm_scm_to_clutter_rect (SCM scm)
+{
+  ClutterRect ret;
+
+  ret.origin.x = scm_to_double (scm_car (scm));
+  ret.origin.y = scm_to_double (scm_cadr (scm));
+  ret.size.width = scm_to_double (scm_caddr (scm));
+  ret.size.height = scm_to_double (scm_cadddr (scm));
+
+  return clutter_rect_copy (&ret);
+}
+
+SCM
+scm_clutter_matrix_to_scm (ClutterMatrix *m)
+{
+  return scm_list_n (scm_from_double (m->xx), /* column 0 */
+		     scm_from_double (m->yx),
+		     scm_from_double (m->zx),
+		     scm_from_double (m->wx),
+		     scm_from_double (m->xy), /* column 1 */
+		     scm_from_double (m->yy),
+		     scm_from_double (m->zy),
+		     scm_from_double (m->wy),
+		     scm_from_double (m->xz), /* column 2 */
+		     scm_from_double (m->yz),
+		     scm_from_double (m->zz),
+		     scm_from_double (m->wz),
+		     scm_from_double (m->xw), /* column 3 */
+		     scm_from_double (m->yw),
+		     scm_from_double (m->zw),
+		     scm_from_double (m->ww),
+		     SCM_UNDEFINED);
+}
+
+ClutterMatrix*
+scm_scm_to_clutter_matrix (SCM scm)
+{
+  ClutterMatrix ret;
+
+  ret.xx = scm_to_double (scm_list_ref (scm, scm_from_int (0)));
+  ret.yx = scm_to_double (scm_list_ref (scm, scm_from_int (1)));
+  ret.zx = scm_to_double (scm_list_ref (scm, scm_from_int (2)));
+  ret.wx = scm_to_double (scm_list_ref (scm, scm_from_int (3)));
+  ret.xy = scm_to_double (scm_list_ref (scm, scm_from_int (4)));
+  ret.yy = scm_to_double (scm_list_ref (scm, scm_from_int (5)));
+  ret.zy = scm_to_double (scm_list_ref (scm, scm_from_int (6)));
+  ret.wy = scm_to_double (scm_list_ref (scm, scm_from_int (7)));
+  ret.xz = scm_to_double (scm_list_ref (scm, scm_from_int (8)));
+  ret.yz = scm_to_double (scm_list_ref (scm, scm_from_int (9)));
+  ret.zz = scm_to_double (scm_list_ref (scm, scm_from_int (10)));
+  ret.wz = scm_to_double (scm_list_ref (scm, scm_from_int (11)));
+  ret.xw = scm_to_double (scm_list_ref (scm, scm_from_int (12)));
+  ret.yw = scm_to_double (scm_list_ref (scm, scm_from_int (13)));
+  ret.zw = scm_to_double (scm_list_ref (scm, scm_from_int (14)));
+  ret.ww = scm_to_double (scm_list_ref (scm, scm_from_int (15)));
+
+  return g_boxed_copy (clutter_matrix_get_type (), &ret);
+}
+
+gboolean
+_wrap_clutter_image_set_data (ClutterImage *image,
+			      guchar *data,
+			      CoglPixelFormat pixel_format,
+			      guint width,
+			      guint height,
+			      guint row_stride,
+			      GError **error)
+{
+  return clutter_image_set_data (image,
+				 (const guint8 *)data,
+				 pixel_format, width, height, row_stride, error);
+}
