@@ -1,5 +1,5 @@
 /* guile-gnome
- * Copyright (C) 2008 Free Software Foundation, Inc.
+ * Copyright (C) 2008,2012,2014 Free Software Foundation, Inc.
  *
  * clutter-support.h:
  *
@@ -33,6 +33,7 @@ ClutterPathNode* scm_scm_to_clutter_path_node (SCM scm);
 
 SCM scm_clutter_margin_to_scm (ClutterMargin *k);
 ClutterMargin* scm_scm_to_clutter_margin (SCM scm);
+SCM wrap_clutter_actor_get_margin (ClutterActor* actor);
 
 SCM scm_clutter_color_to_scm (ClutterColor *c);
 ClutterColor* scm_scm_to_clutter_color (SCM scm);
@@ -51,6 +52,9 @@ ClutterPerspective* scm_scm_to_clutter_perspective (SCM scm);
 SCM wrap_clutter_stage_get_perspective (ClutterStage *stage);
 
 SCM _wrap_clutter_color_from_string (const char *name);
+SCM wrap_clutter_actor_get_background_color (ClutterActor* actor);
+SCM wrap_clutter_text_get_color (ClutterText* text);
+
 
 ClutterUnits* wrap_clutter_units_from_pixels (gint px);
 ClutterUnits* wrap_clutter_units_from_em (gfloat em);
@@ -58,3 +62,22 @@ ClutterUnits* wrap_clutter_units_from_em_for_font (const gchar *font_name, gfloa
 ClutterUnits* wrap_clutter_units_from_mm (gfloat mm);
 ClutterUnits* wrap_clutter_units_from_pt (gfloat pt);
 ClutterUnits* wrap_clutter_units_from_string (const gchar *str);
+
+
+/* Since 1.12 */
+
+SCM scm_clutter_point_to_scm (ClutterPoint *k);
+ClutterPoint* scm_scm_to_clutter_point (SCM scm);
+
+SCM scm_clutter_size_to_scm (ClutterSize *k);
+ClutterSize* scm_scm_to_clutter_size (SCM scm);
+
+SCM scm_clutter_rect_to_scm (ClutterRect *rect);
+ClutterRect* scm_scm_to_clutter_rect (SCM scm);
+
+SCM scm_clutter_matrix_to_scm (ClutterMatrix *m);
+ClutterMatrix* scm_scm_to_clutter_matrix (SCM scm);
+
+gboolean _wrap_clutter_image_set_data (ClutterImage *image, guchar *data,
+				       CoglPixelFormat pixel_format, guint width, guint height,
+				       guint row_stride, GError **error);
